@@ -1,6 +1,6 @@
 /*
  * SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
- * SPDX-FileCopyrightText: 2020 Devin Lin <espidev@gmail.com>
+ * SPDX-FileCopyrightText: 2020-2021 Devin Lin <espidev@gmail.com>
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -24,7 +24,7 @@ class AudioProber : public QAudioProbe
     Q_PROPERTY(int maxVolumes READ maxVolumes WRITE setMaxVolumes NOTIFY maxVolumesChanged)
 
 public:
-    AudioProber(QObject *parent = nullptr) {}
+    AudioProber(QObject *parent = nullptr);
     AudioProber(QObject *parent, QAudioRecorder *source);
     AudioProber(QObject *parent, QMediaPlayer *source);
 
